set more off

**************************************************************************		
**************************************************************************
**        FIGURE 2: SIMULATION-BASED EVIDENCE ON RANDOM ASSIGNMENT
**************************************************************************
**************************************************************************

* create empty dataset for residuals
clear
gen res = .
save STAR_MC_residuals_empty.dta, replace

* load actual data
use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)
keep if gkschool_nofgrep > 0

* actual data: within-school standard deviation in repeater exposure
areg gkclass_nofgrep, absorb(gkschoolid)
predict res, r
sum res
preserve
keep res
saveold STAR_actual_residuals.dta, replace
restore

* generate variables indicating the distribution of students across
* classes in each school
gsort gkschoolid gkclassid -gkclasstag
bysort gkschoolid: gen gkschool_class_id = sum(gkclasstag)
bysort gkclassid: egen gkclass_nstud = total(studentid != "")

bysort gkschoolid: gen _temp = sum(gkclass_nstud) if gkclasstag == 1
bysort gkschoolid gkschool_class_id: egen _temp2 = max(_temp)
forvalues c = 1/8 {
	gen cutoff`c'_temp = _temp2 if gkschool_class_id == `c'
	bysort gkschoolid: egen gkschool_cutoff`c' = max(cutoff`c'_temp)
}
drop *_temp*

* keep only essential variables, save stripped-down version of data
keep gkschoolid gkschool_cutoff* gkofgrepeater
save STAR_MC1.dta, replace

* define monte carlo program
capture program drop mcbalancing
program define mcbalancing, rclass

	use STAR_MC1.dta, clear
	
	* randomly assign students to classes within schools
	gen randclass = .
	gen randnumber = runiform()
	sort gkschoolid randnumber
	bysort gkschoolid: gen gkschool_student_counter = _n
	replace randclass = 1 if gkschool_student_counter <= gkschool_cutoff1
	replace randclass = 2 if gkschool_student_counter > gkschool_cutoff1 & gkschool_student_counter <= gkschool_cutoff2
	replace randclass = 3 if gkschool_student_counter > gkschool_cutoff2 & gkschool_student_counter <= gkschool_cutoff3
	replace randclass = 4 if gkschool_student_counter > gkschool_cutoff3 & gkschool_student_counter <= gkschool_cutoff4
	replace randclass = 5 if gkschool_student_counter > gkschool_cutoff4 & gkschool_student_counter <= gkschool_cutoff5
	replace randclass = 6 if gkschool_student_counter > gkschool_cutoff5 & gkschool_student_counter <= gkschool_cutoff6
	replace randclass = 7 if gkschool_student_counter > gkschool_cutoff6 & gkschool_student_counter <= gkschool_cutoff7
	replace randclass = 8 if gkschool_student_counter > gkschool_cutoff7 & gkschool_student_counter <= gkschool_cutoff8
	
	egen double gkschool_randclass_id = group(gkschoolid randclass)
	bysort gkschool_randclass_id: egen randclass_nofgrep = total(gkofgrepeater == 1)
	gen randclass_ofgrep_dummy = (randclass_nofgrep>0)
	
	areg randclass_nofgrep, absorb(gkschoolid)
	predict res, r

	sum res
	return scalar sd = r(sd)
	
	keep res
	append using STAR_MC_residuals.dta
	saveold STAR_MC_residuals.dta, replace
	
end

* simulate and save residuals (NOTE: if you have this on Dropbox or some
* other cloud folder that is frequently synched, turn this off!)
copy STAR_MC_residuals_empty.dta STAR_MC_residuals.dta, replace // makes sure that we start from an empty residuals dataset
set seed 12345
simulate r(sd), reps(1000): mcbalancing

* density plots of within-school residuals in the actual vs simulated data 
use STAR_actual_residuals.dta, clear
append using STAR_MC_residuals.dta, gen(simulated)

kdensity res if simulated == 0, nodraw
local b = `r(bwidth)'
tw (kdensity res if simulated == 0, bwidth(`b') legend(label(1 "actual data")) lcolor(black) lpattern(solid) ylabel( ,angle(0)) xscale(r(-5.2 5.2)) xlabel(-4(2)4) xtitle("residuals", size(medsmall) height(5)) ytitle("density", size(medsmall) height(5))) ///
   (kdensity res if simulated == 1, bwidth(`b') legend(label(2 "simulated data")) lcolor(gs6) lpattern(dash))

erase STAR_MC_residuals_empty.dta
erase STAR_actual_residuals.dta
erase STAR_MC_residuals.dta
erase STAR_MC1.dta
