set more off

**************************************************************************
**************************************************************************
**                FIGURE 4: QUANTILE REGRESSION RESULTS
**************************************************************************
**************************************************************************


**************************************************************************
*                    end-of-kindergarten math scores                     
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* OLS effect
qui areg gkmath_std gkclass_ofgrep_dummy gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
mat Eb = e(b)
local ols = Eb[1,1]

* two-step estimation as in Canay (2011)
qui reg gkmath_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0
predict theta_hat, xb
gen deviation = gkmath_std - theta_hat
bys gkschoolid: egen eta_hat = mean(deviation)
gen ts_hat = gkmath_std - eta_hat

forval i = 5(5)95 {
	tempfile quantile`i'
	local q = `i' / 100
	bsqreg ts_hat gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, quantile(`q') reps(100)
	parmest, level(95) saving(`"`quantile`i''"', replace)
}

drop _all
append using `"`quantile5'"'  `"`quantile10'"' `"`quantile15'"' `"`quantile20'"' `"`quantile25'"' `"`quantile30'"' `"`quantile35'"' `"`quantile40'"' `"`quantile45'"' `"`quantile50'"'
append using `"`quantile55'"' `"`quantile60'"' `"`quantile65'"' `"`quantile70'"' `"`quantile75'"' `"`quantile80'"' `"`quantile85'"' `"`quantile90'"' `"`quantile95'"'

keep if parm == "gkclass_ofgrep_dummy"

gen quantile = _n / 20
gen fakeols = 0

tw (connected estimate quantile, lpattern(solid) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected min95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected max95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (line fakeols quantile, lpattern(dash) lcolor(gs6)) ///
   , yline(0, lcolor(gs6)) yline(`ols', lcolor(gs6) lpattern(dash)) ylabel(-.3(.1)0, angle(0)) ///
   title("Kindergarten math score", size(large)) xlabel(.1(.1).9)  ///
   xtitle("quantile") ///
   legend(on order(1 2 4) label(1 "repeater-exposure effect") label(2 "95% confidence bounds") label(4 "mean effect")) name(gk_math, replace)


**************************************************************************
*             		  	 non-cognitive skills index                  
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* OLS effect
qui areg g4g8noncog_std gkclass_ofgrep_dummy gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
mat Eb = e(b)
local ols = Eb[1,1]

qui reg g4g8noncog_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0
predict theta_hat, xb
gen deviation = g4g8noncog_std - theta_hat
bys gkschoolid: egen eta_hat = mean(deviation)
gen ts_hat = g4g8noncog_std - eta_hat

forval i = 5(5)95 {
	tempfile quantile`i'
	local q = `i' / 100
	global studentbg = "male black gkfreelunch age_years gkoldforgrade"
	bsqreg ts_hat gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, quantile(`q') reps(100)
	parmest, level(95) saving(`"`quantile`i''"', replace)
}

drop _all
append using `"`quantile5'"'  `"`quantile10'"' `"`quantile15'"' `"`quantile20'"' `"`quantile25'"' `"`quantile30'"' `"`quantile35'"' `"`quantile40'"' `"`quantile45'"' `"`quantile50'"'
append using `"`quantile55'"' `"`quantile60'"' `"`quantile65'"' `"`quantile70'"' `"`quantile75'"' `"`quantile80'"' `"`quantile85'"' `"`quantile90'"' `"`quantile95'"'

keep if parm == "gkclass_ofgrep_dummy"

gen quantile = _n / 20
gen fakeols = 0

tw (connected estimate quantile, lpattern(solid) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected min95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected max95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (line fakeols quantile, lpattern(dash) lcolor(gs6)) ///
   , yline(0, lcolor(gs6)) yline(`ols', lcolor(gs6) lpattern(dash)) ///
   title("Non-cognitive skills index", size(large)) xlabel(.1(.1).9) ylabel(-.2(.2).4, angle(0)) ///
   xtitle("quantile") ///
   legend(on order(1 2 4) label(1 "repeater-exposure effect") label(2 "95% confidence bounds") label(4 "mean effect") ) nodraw name(non_cog_index, replace) // saving(../results/quantiles_gkmath.gph, replace)


**************************************************************************
*                        eighth-grade math scores                        
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* OLS effect
qui areg math94_std gkclass_ofgrep_dummy gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
mat Eb = e(b)
local ols = Eb[1,1]

* two-step estimation as in Canay (2011)
qui reg math94_std gkclass_ofgrep_dummy $studentbg if gkofgrepeater == 0
predict theta_hat, xb
gen deviation = math94_std - theta_hat
bys gkschoolid: egen eta_hat = mean(deviation)
gen ts_hat = math94_std - eta_hat

forval i = 5(5)95 {
	tempfile quantile`i'
	local q = `i'/100
	bsqreg ts_hat gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, quantile(`q') reps(100)
	parmest, level(95) saving(`"`quantile`i''"', replace)
}

drop _all
append using `"`quantile5'"'  `"`quantile10'"' `"`quantile15'"' `"`quantile20'"' `"`quantile25'"' `"`quantile30'"' `"`quantile35'"' `"`quantile40'"' `"`quantile45'"' `"`quantile50'"'
append using `"`quantile55'"' `"`quantile60'"' `"`quantile65'"' `"`quantile70'"' `"`quantile75'"' `"`quantile80'"' `"`quantile85'"' `"`quantile90'"' `"`quantile95'"'

keep if parm == "gkclass_ofgrep_dummy"

gen quantile = _n / 20
gen fakeols = 0

tw (connected estimate quantile, lpattern(solid) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected min95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected max95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (line fakeols quantile, lpattern(dash) lcolor(gs6)) ///
   , yline(0, lcolor(gs6)) yline(`ols', lcolor(gs6) lpattern(dash)) ///
   title("Eighth-grade math score", size(large)) xlabel(.1(.1).9) ylabel(-.1(.1).3, angle(0)) ///
   xtitle("quantile")  ///
   legend(on order(1 2 4) label(1 "repeater-exposure effect") label(2 "95% confidence bounds") label(4 "mean effect") ) nodraw name(g8_math, replace)


**************************************************************************
*                   			 HS GPA                    
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)

* OLS effect
qui areg hsgpa gkclass_ofgrep_dummy gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
mat Eb = e(b)
local ols = Eb[1,1]

* two-step estimation as in Canay (2011)
qui reg hsgpa gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0
predict theta_hat, xb
gen deviation = hsgpa - theta_hat
bys gkschoolid: egen eta_hat = mean(deviation)
gen ts_hat = hsgpa - eta_hat

forval i = 5(5)95 {
	tempfile quantile`i'
	local q = `i'/100
	bsqreg ts_hat gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, quantile(`q') reps(100)
	parmest, level(95) saving(`"`quantile`i''"', replace)
}

drop _all
append using `"`quantile5'"'  `"`quantile10'"' `"`quantile15'"' `"`quantile20'"' `"`quantile25'"' `"`quantile30'"' `"`quantile35'"' `"`quantile40'"' `"`quantile45'"' `"`quantile50'"'
append using `"`quantile55'"' `"`quantile60'"' `"`quantile65'"' `"`quantile70'"' `"`quantile75'"' `"`quantile80'"' `"`quantile85'"' `"`quantile90'"' `"`quantile95'"'

keep if parm == "gkclass_ofgrep_dummy"

gen quantile = _n / 20
gen fakeols = 0

tw (connected estimate quantile, lpattern(solid) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected min95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (connected max95 quantile, lpattern(dash_dot) lcolor(black) msymbol(none) mcolor(gs2)) ///
   (line fakeols quantile, lpattern(dash) lcolor(gs6)) ///
   , yline(0, lcolor(gs6)) yline(0.552, lcolor(gs6) lpattern(dash)) ///
   title("High school GPA", size(large)) xlabel(.1(.1).9) ylabel(-1(1)2, angle(0)) ///
   xtitle("quantile")  ///
   legend(on order(1 2 4) label(1 "repeater-exposure effect") label(2 "95% confidence bounds") label(4 "mean effect")) nodraw name(hs_gpa, replace)


**************************************************************************
*		                   combine estimates
**************************************************************************
	
grc1leg gk_math non_cog_index g8_math hs_gpa
