set more off

**************************************************************************
**************************************************************************
**     ONLINE APPENDIX TABLE C.2: EFFECTS ON LATER CLASS COMPOSITION
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)


**************************************************************************
*		              some descriptive statistics
**************************************************************************

* how many students are still in STAR in G1, G2, G3?
tab g1 if gk == 1
tab g2 if gk == 1
tab g3 if gk == 1

* any missing values in peer characteristics? -- see below
nmissing g1classlom_male g1classlom_black g1classlom_g1freelunch g1classlom_age_years g1classlom_g1oldforgrade if gk == 1 & g1 == 1 // 34 missing values in peers' g1freelunch -- reason: no data available in classes 130 and 185
nmissing g2classlom_male g2classlom_black g2classlom_g2freelunch g2classlom_age_years g2classlom_g2oldforgrade if gk == 1 & g2 == 1 // 126 missing values in peers' g2freelunch -- reason: no data available in classes 25-28, 161-165, and 201
nmissing g3classlom_male g3classlom_black g3classlom_g3freelunch g3classlom_age_years g3classlom_g3oldforgrade if gk == 1 & g3 == 1 // 84 missing values in peers' g3freelunch -- reason: no data available in classes 11, 18, 142, 199, 200, 201, 311

* any missing values in teacher characteristics? -- some
nmissing g1teachblack g1tyears g1teachadvdeg if gk == 1 & g1 == 1 
nmissing g2teachblack g2tyears g2teachadvdeg if gk == 1 & g2 == 1
nmissing g3teachblack g3tyears g3teachadvdeg if gk == 1 & g3 == 1


**************************************************************************
*			                       table
**************************************************************************

* panel A: grade 1
eststo clear

qui eststo: areg g1classlom_male gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1classlom_black gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1classlom_g1freelunch gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1classlom_age_years gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1classlom_g1oldforgrade gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1teachblack gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1tyears gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g1==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g1teachadvdeg gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) label nogaps se star(* 0.10 ** 0.05 *** 0.01)  varwidth(28) b(3)

* panel B: grade 2
eststo clear

qui eststo: areg g2classlom_male gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2classlom_black gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2classlom_g2freelunch gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2classlom_age_years gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2classlom_g2oldforgrade gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2teachblack gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2tyears gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g2teachadvdeg gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g2==1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) label nogaps se star(* 0.10 ** 0.05 *** 0.01)  varwidth(28) b(3)

* panel C: grade 3
eststo clear

qui eststo: areg g3classlom_male gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3classlom_black gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3classlom_g3freelunch gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3classlom_age_years gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3classlom_g3oldforgrade gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3teachblack gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3tyears gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g3teachadvdeg gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater==0 & gk==1 & g3==1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) label nogaps se star(* 0.10 ** 0.05 *** 0.01)  varwidth(28) b(3)
