set more off

**************************************************************************
**************************************************************************
**    ONLINE APPENDIX TABLE B.6: CONTROLLING FOR CLASS CHARACTERISTICS
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)


* descriptives: correlations between treatment and classmates' characteristics
eststo clear

qui eststo: areg gkclasslom_male gkclass_ofgrep_dummy if gkofgrepeater == 0, absorb(gkschoolid)
qui eststo: areg gkclasslom_black gkclass_ofgrep_dummy if gkofgrepeater == 0, absorb(gkschoolid)
qui eststo: areg gkclasslom_gkfreelunch gkclass_ofgrep_dummy if gkofgrepeater == 0, absorb(gkschoolid)
qui eststo: areg gkclasslom_age_years gkclass_ofgrep_dummy if gkofgrepeater == 0, absorb(gkschoolid)
qui eststo: areg gkclasslom_gkoldforgrade gkclass_ofgrep_dummy if gkofgrepeater == 0, absorb(gkschoolid)

esttab, keep(gkclass_ofgrep_dummy) mtitles("% male" "% black" "% freel" "mean age" "% ofg") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 


**************************************************************************
* 						      restults table
**************************************************************************

* share male
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom_male gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom_male gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom_male gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom_male gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 

* share black
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom_black gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom_black gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom_black gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom_black gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 

* share free lunch
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom_gkfreelunch gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom_gkfreelunch gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom_gkfreelunch gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom_gkfreelunch gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 

* average age
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom_age_years gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom_age_years gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom_age_years gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom_age_years gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 

* share old for grade
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom_gkoldforgrade gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom_gkoldforgrade gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom_gkoldforgrade gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom_gkoldforgrade gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 

* all characteristics jointly		
eststo clear

qui eststo: areg gkmath_std gkclass_ofgrep_dummy gkclasslom* gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg math94_std gkclass_ofgrep_dummy gkclasslom* gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4g8noncog_std gkclass_ofgrep_dummy gkclasslom* gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsindex_std gkclass_ofgrep_dummy gkclasslom* gksmallclass $studentbg if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gkclasslom*) mtitles("KG math" "G8 math" "Noncog" "HS index") label r2 compress nogaps se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3) 
