set more off

**************************************************************************
**************************************************************************
**	ONLINE APPENDIX TABLE C.9: MORE RESULTS FOR DISAGGREGATED OUTCOMES
**************************************************************************
**************************************************************************

use STAR_students_clean.dta, clear
keep if gk == 1 & (gkrepeater == 0 | gkofgrepeater == 1)


**************************************************************************
*                        panel A: main estimates
**************************************************************************

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
*               panel B: heterogeneity by predicted ability
**************************************************************************

egen gkcomposite = rowmean(gkmath_std gkread_std)
gen predicted_ability = .
levelsof studentid, local(students)
foreach s of local students {
	qui reg gkcomposite male black gkfreelunch age_years gkoldforgrade if gkofgrepeater == 0 & studentid != "`s'"
	qui predict _temp if gkofgrepeater == 0 & studentid == "`s'", xb
	qui replace predicted_ability = _temp if studentid == "`s'"
	qui drop _temp
} 
qui sum predicted_ability if gkofgrepeater == 0
gen predicted_ability_std = (predicted_ability - r(mean)) / sqrt(r(Var))

gen predicted_ability_X_ofgrep = predicted_ability_std * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy predicted_ability_X_ofgrep predicted_ability gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy predicted_ability_X_ofgrep) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
	
		
**************************************************************************
* 	              panel C: heterogeneity by class size
**************************************************************************

gen gksmallclass_X_ofgrep = gksmallclass * gkclass_ofgrep_dummy

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy gksmallclass_X_ofgrep $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy gksmallclass_X_ofgrep) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)

		
**************************************************************************
* 	   panel D: controlling for the main non-cognitive skills index
**************************************************************************

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy g4g8noncog_std $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy g4g8noncog_std $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy g4g8noncog_std $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
* 			   panel E: sample restricted to school stayers
**************************************************************************

gen school_stayer=0
replace school_stayer=1 if (gkschoolid == g1schoolid) & (g1schoolid == g2schoolid) & (g2schoolid == g3schoolid)

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & school_stayer==1, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
* 	  panel F: sample excluding special education/instruction repeaters
**************************************************************************

bysort gkclassid: egen gkclass_nspecedrep=total((gkofgrepeater==1)*(gkspeced==1)) if gk==1
bysort gkclassid: egen gkclass_nspecinrep=total((gkofgrepeater==1)*(gkspecin==1)) if gk==1

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecedrep==0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecedrep==0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy $studentbg gksmallclass if gkofgrepeater == 0 & gkclass_nspecedrep==0 & gkclass_nspecinrep==0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)


**************************************************************************
* 		panel G: heterogeneity by the number of repeaters in class
**************************************************************************
		
gen gkclass_nofgrep_1 = (gkclass_nofgrep == 1)
gen gkclass_nofgrep_2 = (gkclass_nofgrep == 2)
gen gkclass_nofgrep_3_5 = ((gkclass_nofgrep > 2) * (gkclass_nofgrep < .))

eststo clear

qui eststo: areg g4pteffr_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5 $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_nofgrep_1 gkclass_nofgrep_2 gkclass_nofgrep_3_5) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
		
		
**************************************************************************
*  	panel H: controlling for classmates' demographic characteristics
**************************************************************************

eststo clear

qui eststo: areg g4pteffr_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptinit_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptappr_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g4ptdpln_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8pteffr_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptinit_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptappr_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg g8ptdpln_std gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgpa gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hsgraduate gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)
qui eststo: areg hstest gkclass_ofgrep_dummy gkclasslom* $studentbg gksmallclass if gkofgrepeater == 0, absorb(gkschoolid) cluster(gkclassid)

esttab, keep(gkclass_ofgrep_dummy) nomtitles label r2 compress se star(* 0.10 ** 0.05 *** 0.01) varwidth(28) b(3)
